pub(crate) fn le_repr<F: PrimeField>(fe: &F) -> F::ReprExpand description
Get the little endian representation of a field, namely a scalar.
pub(crate) fn le_repr<F: PrimeField>(fe: &F) -> F::ReprGet the little endian representation of a field, namely a scalar.