wnaf_multi_exp

Function wnaf_multi_exp 

pub(crate) fn wnaf_multi_exp<'a, G, I>(terms: I) -> G
where G: Group, I: Clone + IntoIterator<Item = (&'a [G], &'a [Digit], usize)>,
Performs wNAF multi-exponentiation using the interleaved window method, also known as Straus’s method.

The key insight is that when computing this sum by means of additions and doublings, the doublings can be shared by performing the additions within an inner loop.