pub(crate) fn wnaf_multi_exp<'a, G, I>(terms: I) -> GExpand description
Performs wNAF multi-exponentiation using the interleaved window method, also known as Straus’s method.
The key insight is that when computing this sum by means of additions and doublings, the doublings can be shared by performing the additions within an inner loop.