pub(crate) fn wnaf_table<G: Group>(table: &mut [G], base: &G, window: usize)Expand description
Computes a wNAF window table for the given base and window size.
For a window of size w non-zero wNAF digits are odd and have magnitude at most 2^(w-1) - 1.
The table is indexed by |digit| / 2, so the required size is (2^(w-1) - 1) / 2 + 1 = 2^(w-2)
entries.